@@ -224,32 +224,4 @@ res = a.run(**res)
 assert res.get(__SYS_STAGE__, None) == StageStatus.COMPLETE
 res.pop(__SYS_REPLY__)
 res = a.run(**res)
-assert res.get(__SYS_STAGE__, None) == StageStatus.COMPLETE
-
-
-class SwitchStage(Stage):
-
-    def __init__(self, stages_filter):
-        super(SwitchStage, self).__init__()
-        self.stage_type = StageType.SWITCH
-        self.stages_filter = stages_filter
-
-    @staticmethod
-    def is_first_access(data, stage_id):
-        return False
-
-    def find_new_stages(self, kwargs):
-
-        print(f"filter_tuple: {self.stages_filter}")
-        for filter_tuple in self.stages_filter:
-            print(f"filter_tuple: {filter_tuple}")
-            label, text, stages_label = filter_tuple
-            try:
-                if self.get_default_var(kwargs, label) == text:
-                    return stages_label
-            except KeyError as e:
-                print(e)
-        raise RuntimeError
-
-    def is_fit_needs_n_gen_entity(self, kwargs) -> (bool, dict):
-        raise RuntimeError("Not support run method, Please use `MultiAgent` to replace `Agent`")
+assert res.get(__SYS_STAGE__, None) == StageStatus.COMPLETE
\ No newline at end of file
